# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import modern_logic_client
from modern_logic_client.api.alerts_api import AlertsApi  # noqa: E501
from modern_logic_client.rest import ApiException


class TestAlertsApi(unittest.TestCase):
    """AlertsApi unit test stubs"""

    def setUp(self):
        self.api = AlertsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_alert_alert_id_get(self):
        """Test case for alert_alert_id_get

        Get Alert Details  # noqa: E501
        """
        pass

    def test_alert_get(self):
        """Test case for alert_get

        List Alerts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
