# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import modern_logic_client
from modern_logic_client.models.inline_response2008 import InlineResponse2008  # noqa: E501
from modern_logic_client.rest import ApiException


class TestInlineResponse2008(unittest.TestCase):
    """InlineResponse2008 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse2008(self):
        """Test InlineResponse2008"""
        # FIXME: construct object with mandatory attributes with example values
        # model = modern_logic_client.models.inline_response2008.InlineResponse2008()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
