# coding: utf-8

"""
    Modern Logic Api

    Manage and version your customer decision logic outside of your codebase  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: info@usemodernlogic.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "modern-logic-client"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Modern Logic Api",
    license='MIT',
    author_email="info@usemodernlogic.com",
    url = 'https://github.com/latourette359/modern_logic_client',
    download_url = "https://github.com/latourette359/modern_logic_client/archive/refs/tags/1.0.0.tar.gz",
    keywords=["Swagger", "Modern Logic Api"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Manage and version your customer decision logic outside of your codebase  # noqa: E501
    """
)
